pub struct DmaRxTxBuf { /* private fields */ }Available on crate feature
unstable only.Expand description
DMA transmit and receive buffer.
This is a (single) contiguous buffer linked together by two sets of DMA descriptors of length 4092 each. It can be used for simultaneously transmitting to and receiving from a peripheral’s FIFO. These are typically full-duplex transfers.
Implementations
Sourceimpl DmaRxTxBuf
impl DmaRxTxBuf
Sourcepub fn new(
rx_descriptors: DmaAlignedMut<'static, [DmaDescriptor]>,
tx_descriptors: DmaAlignedMut<'static, [DmaDescriptor]>,
buffer: DmaAlignedMut<'static, [u8]>,
) -> Result<Self, DmaBufError>
pub fn new( rx_descriptors: DmaAlignedMut<'static, [DmaDescriptor]>, tx_descriptors: DmaAlignedMut<'static, [DmaDescriptor]>, buffer: DmaAlignedMut<'static, [u8]>, ) -> Result<Self, DmaBufError>
Creates a new DmaRxTxBuf from some descriptors and a buffer.
Sourcepub fn set_burst_config(
&mut self,
burst: BurstConfig,
) -> Result<(), DmaBufError>
pub fn set_burst_config( &mut self, burst: BurstConfig, ) -> Result<(), DmaBufError>
Configures the DMA to use burst transfers to access this buffer.
Sourcepub fn split(
self,
) -> (DmaAlignedMut<'static, [DmaDescriptor]>, DmaAlignedMut<'static, [DmaDescriptor]>, DmaAlignedMut<'static, [u8]>)
pub fn split( self, ) -> (DmaAlignedMut<'static, [DmaDescriptor]>, DmaAlignedMut<'static, [DmaDescriptor]>, DmaAlignedMut<'static, [u8]>)
Consume the buf, returning the rx descriptors, tx descriptors and buffer.
Sourcepub fn as_mut_slice(&mut self) -> &mut [u8] ⓘ
pub fn as_mut_slice(&mut self) -> &mut [u8] ⓘ
Returns the entire buf as a slice than can be written.
Sourcepub fn set_length(&mut self, len: usize)
pub fn set_length(&mut self, len: usize)
Reset the descriptors to only transmit/receive len amount of bytes
with this buf.
len must be less than or equal to the buffer size.